@@ -2,7 +2,7 @@
 #
 #   file: lib/Version/Dotted.pm
 #
-#   Copyright © 2016 Van de Bugger.
+#   Copyright © 2017 Van de Bugger.
 #
 #   This file is part of perl-Version-Dotted.
 #
@@ -19,8 +19,8 @@
 #
 #   ---------------------------------------------------------------------- copyright and license ---
 
-#pod =for :this This is C<Version::Dotted> module/class documentation. Read it first because it contains
-#pod many relevant details, and use one of subclasses.
+#pod =for :this This is C<Version::Dotted> module documentation. Read it first because it contains many
+#pod relevant details, and use one of subclasses.
 #pod
 #pod =for :those General topics like getting source, building, installing, bug reporting and some others
 #pod are covered in the F<README>.
@@ -61,10 +61,9 @@
 #pod
 #pod =head2 Purpose
 #pod
-#pod C<Version::Dotted> is I<not> a replacement for C<version>, if you are going to declare version of
-#pod your module or compare versions, just L<use C<version>|/Using version>.
-#pod
-#pod C<Version::Dotted> is designed for two purposes:
+#pod C<Version::Dotted> is I<authoring time> extension to C<version>. It means C<Version::Dotted> and
+#pod its subclasses are intended to be used in authoring tools (like C<Dist::Zilla> plugins) when author
+#pod prepares a distribution. C<Version::Dotted> and its subclasses serve for two purposes:
 #pod
 #pod =over
 #pod
@@ -74,11 +73,13 @@
 #pod
 #pod =item 2
 #pod
-#pod To implement well-defined approach(es) to trial versions which do(es) not rely on underscore
-#pod character to be compatible with C<version> module 0.77 or later.
+#pod To implement alternative trial version criteria not depending on underscore character.
 #pod
 #pod =back
 #pod
+#pod C<Version::Dotted> is I<not> required to build, install, and use module(s) from prebuilt
+#pod distribution, core C<version> works at these stages.
+#pod
 #pod See also L</WHY?>.
 #pod
 #pod =head2 Types of Versions
@@ -86,8 +87,8 @@
 #pod Historically, two types of version numbers are used in Perl: L<decimal|/Decimal Versions> and
 #pod L<dotted|/Dotted Versions>.
 #pod
-#pod C<Version::Dotted> handles dotted versions, obviously, and only: no support for decimal versions is
-#pod provided intentionally.
+#pod C<Version::Dotted> handles only dotted versions, no support for decimal versions is provided
+#pod intentionally.
 #pod
 #pod =head2 Bumping
 #pod
@@ -99,17 +100,17 @@
 #pod
 #pod Firstly, C<Version::Dotted> prefers "trial" term to "alpha" (see L</Non-Stable Releases>).
 #pod
-#pod Secondly, trial versions are not denoted by underscore character anymore (see L</WHY?>). Definition
-#pod of trial version is left for subclasses.
+#pod Secondly, trial versions are not denoted by underscore character anymore (see L</WHY?>).
+#pod C<Version::Dotted> defines interface, exact criteria are implemented in subclasses.
 #pod
 #pod =head2 Parent(s)
 #pod
 #pod C<Version::Dotted> is heavily influenced by C<Perl::Version>, but C<Version::Dotted> is not a
 #pod subclass of C<Perl::Version>.
 #pod
-#pod C<Version::Dotted> it is a subclass of C<version>. The class narrows C<version> —
-#pod C<Version::Dotted> creates only dotted (aka dotted-decimal) version objects. The class extends
-#pod C<version> — C<Version::Dotted> objects are modifiable.
+#pod C<Version::Dotted> it is a subclass of C<version>. C<Version::Dotted> extends C<version> —
+#pod C<Version::Dotted> objects are modifiable, but it also narrows C<version> — C<Version::Dotted>
+#pod creates only dotted (aka dotted-decimal) version objects.
 #pod
 #pod =head2 Error Reporting
 #pod
@@ -132,7 +133,7 @@ use warnings::register;
 use version 0.77 qw{};
 
 # ABSTRACT: Bump a dotted version, check if version is trial
-our $VERSION = 'v0.0.0_07'; # TRIAL VERSION
+our $VERSION = 'v0.0.1'; # VERSION
 
 use parent 'version';
 use overload (
@@ -330,7 +331,7 @@ sub part {
 #pod     $v->bump( 1 );      # $v == v1.3
 #pod     $v->bump( 0 );      # $v == v2
 #pod
-#pod If index is larger than actual number of version parts (minus one), missed parts are autovivified:
+#pod If index is larger than actual number of version parts, missed parts are autovivified:
 #pod
 #pod     $v->bump( 5 );      # $v == v2.0.0.0.0.1
 #pod
@@ -552,12 +553,15 @@ sub numify {
 #pod
 #pod     $v = qv( $arg );    # same as $v = Version::Dotted->new( $arg );
 #pod
+#pod (If the function is imported from C<Version::Dotted> subclass, it would be shortcut for
+#pod C<Version::Dotted::Subclass-E<gt>new>.)
+#pod
 #pod The function is prototyped. It takes one scalar argument:
 #pod
 #pod     ( $v, $w ) = qv v1.2.3, v1.2.3;
 #pod
 #pod C<$v> will be a C<Dotted::Version> object, C<$w> will be a v-string. (C<version>'s C<qv> grabs
-#pod entire list but uses only the first argument, C<$w> would be undefined.)
+#pod entire list but uses only the first argument, C<$w> will be undefined.)
 #pod
 #pod Note: There is no function C<qv> in C<Version::Dotted> package, the function is installed into
 #pod importer package by explicit request, see L</"EXPORT">.
@@ -630,9 +634,8 @@ sub import {                                    ## no critic ( RequireArgUnpacki
 #pod     version->parse( '0.003010' )    # version object
 #pod
 #pod Floating-point numbers can be compared, but lose trailing zeros. Strings do not lose trailing
-#pod zeros, but cannot be compared (string comparison operators are not suitable for comparing
-#pod versions). C<version> objects does not lose trailing zeros, can be easily compared, but cannot be
-#pod modified.
+#pod zeros, but string comparison operators are not suitable for comparing versions. C<version> objects
+#pod does not lose trailing zeros, can be easily compared, but cannot be modified.
 #pod
 #pod See also: L<version::Internals/Decimal Versions>.
 #pod
@@ -682,13 +685,13 @@ sub import {                                    ## no critic ( RequireArgUnpacki
 #pod
 #pod =note Non-Stable Releases
 #pod
-#pod Perl terminology in this area in not well-defined and not consistently used:
+#pod Perl terminology in this area is not well-defined and not consistently used:
 #pod
 #pod =over
 #pod
 #pod =item *
 #pod
-#pod The C<version> module declares any version with underscore character (e. g. 'v1.2.3_4') to be an
+#pod The C<version> module declares any version with underscore character (e. g. C<'v1.2.3_4'>) to be an
 #pod "alpha" version. C<version::Internals> refers to CPAN convention "to note unstable releases with an
 #pod underscore in the version string".
 #pod
@@ -698,7 +701,7 @@ sub import {                                    ## no critic ( RequireArgUnpacki
 #pod C<unstable>. Word "alpha" is used in the description of C<unstable> release, while C<testing>
 #pod release is described as "beta". There is also requirement that C<stable> release version should not
 #pod contain underscore. (There is no requirement that C<unstanble> and C<testing> releases should
-#pod underscore.)
+#pod contain underscore.)
 #pod
 #pod =item *
 #pod
@@ -746,25 +749,31 @@ sub import {                                    ## no critic ( RequireArgUnpacki
 #pod
 #pod = L<Version::Next>
 #pod
-#pod TODO
+#pod It provides authoring time subroutine to "increment module version numbers simply and correctly",
+#pod works with both dotted and decimal versions, but it "no longer supports dotted-decimals with alpha
+#pod elements".
 #pod
 #pod = L<SemVer>
 #pod
-#pod TODO
+#pod It implements L<Semantic Versioning 1.0.0|http://semver.org/spec/v1.0.0.html> with no changes (?).
+#pod C<SemVer> allows alphanumeric pre-release versions like C<'1.2.3-alpha1'> and orders them properly:
+#pod 1.2.3-alpha < 1.2.3-beta < 1.2.3. However, C<SemVer> is not I<authoring time> tool, it should be
+#pod used in runtime also to provide correct ordering: C<version> does not recognize properly
+#pod pre-release alphanumeric versions.
 #pod
 #pod = L<Version::Dotted::Semantic>
 #pod
-#pod Subclass implementing adaptation of Semantic Versioning.
+#pod Subclass implementing adaptation of Semantic Versioning, part of this distribution.
 #pod
 #pod = L<Version::Dotted::Odd>
 #pod
-#pod Subclass implementing odd/even versioning scheme.
+#pod Subclass implementing odd/even versioning scheme, part of this distribution.
 #pod
 #pod =end :list
 #pod
 #pod =head1 COPYRIGHT AND LICENSE
 #pod
-#pod Copyright (C) 2016 Van de Bugger
+#pod Copyright (C) 2017 Van de Bugger
 #pod
 #pod License GPLv3+: The GNU General Public License version 3 or later
 #pod <http://www.gnu.org/licenses/gpl-3.0.txt>.
@@ -787,8 +796,8 @@ sub import {                                    ## no critic ( RequireArgUnpacki
 #pod
 #pod =head1 WHAT?
 #pod
-#pod C<Version::Dotted> and its subclasses complement standard C<version> class with bump operation and
-#pod (re)define trial versions differently.
+#pod C<Version::Dotted> and its subclasses are I<authoring time> extensions to core C<version> class:
+#pod they complement C<version> with bump operation and implement alternative trial version criteria.
 #pod
 #pod =cut
 
@@ -829,7 +838,7 @@ sub import {                                    ## no critic ( RequireArgUnpacki
 #pod
 #pod was true before, is false now.
 #pod
-#pod Thus, C<Perl::Version> is broken and it is not clear when and how it will be fixed. But
+#pod Thus, C<Perl::Version> is broken and it is not clear when and I<how> it will be fixed. But
 #pod
 #pod =over
 #pod
@@ -850,7 +859,7 @@ sub import {                                    ## no critic ( RequireArgUnpacki
 #pod
 #pod (BTW: Requirement #2 effectively means that new method should not rely on underscores.)
 #pod
-#pod C<Version::Dotted> fulfills my requirements.
+#pod C<Version::Dotted> fulfills these requirements.
 #pod
 #pod =cut
 
@@ -871,16 +880,15 @@ Version::Dotted - Bump a dotted version, check if version is trial
 
 =head1 VERSION
 
-Version v0.0.0_07, released on 2017-01-03 22:12 UTC.
-This is a B<trial release>.
+Version v0.0.1, released on 2017-01-04 21:35 UTC.
 
 =head1 WHAT?
 
-C<Version::Dotted> and its subclasses complement standard C<version> class with bump operation and
-(re)define trial versions differently.
+C<Version::Dotted> and its subclasses are I<authoring time> extensions to core C<version> class:
+they complement C<version> with bump operation and implement alternative trial version criteria.
 
-This is C<Version::Dotted> module/class documentation. Read it first because it contains
-many relevant details, and use one of subclasses.
+This is C<Version::Dotted> module documentation. Read it first because it contains many
+relevant details, and use one of subclasses.
 
 General topics like getting source, building, installing, bug reporting and some others
 are covered in the F<README>.
@@ -921,10 +929,9 @@ are covered in the F<README>.
 
 =head2 Purpose
 
-C<Version::Dotted> is I<not> a replacement for C<version>, if you are going to declare version of
-your module or compare versions, just L<use C<version>|/Using version>.
-
-C<Version::Dotted> is designed for two purposes:
+C<Version::Dotted> is I<authoring time> extension to C<version>. It means C<Version::Dotted> and
+its subclasses are intended to be used in authoring tools (like C<Dist::Zilla> plugins) when author
+prepares a distribution. C<Version::Dotted> and its subclasses serve for two purposes:
 
 =over
 
@@ -934,11 +941,13 @@ To bump a dotted version.
 
 =item 2
 
-To implement well-defined approach(es) to trial versions which do(es) not rely on underscore
-character to be compatible with C<version> module 0.77 or later.
+To implement alternative trial version criteria not depending on underscore character.
 
 =back
 
+C<Version::Dotted> is I<not> required to build, install, and use module(s) from prebuilt
+distribution, core C<version> works at these stages.
+
 See also L</WHY?>.
 
 =head2 Types of Versions
@@ -946,8 +955,8 @@ See also L</WHY?>.
 Historically, two types of version numbers are used in Perl: L<decimal|/Decimal Versions> and
 L<dotted|/Dotted Versions>.
 
-C<Version::Dotted> handles dotted versions, obviously, and only: no support for decimal versions is
-provided intentionally.
+C<Version::Dotted> handles only dotted versions, no support for decimal versions is provided
+intentionally.
 
 =head2 Bumping
 
@@ -959,17 +968,17 @@ part of C<v1.2.4> gives C<v1.3> (the third part is dropped).
 
 Firstly, C<Version::Dotted> prefers "trial" term to "alpha" (see L</Non-Stable Releases>).
 
-Secondly, trial versions are not denoted by underscore character anymore (see L</WHY?>). Definition
-of trial version is left for subclasses.
+Secondly, trial versions are not denoted by underscore character anymore (see L</WHY?>).
+C<Version::Dotted> defines interface, exact criteria are implemented in subclasses.
 
 =head2 Parent(s)
 
 C<Version::Dotted> is heavily influenced by C<Perl::Version>, but C<Version::Dotted> is not a
 subclass of C<Perl::Version>.
 
-C<Version::Dotted> it is a subclass of C<version>. The class narrows C<version> —
-C<Version::Dotted> creates only dotted (aka dotted-decimal) version objects. The class extends
-C<version> — C<Version::Dotted> objects are modifiable.
+C<Version::Dotted> it is a subclass of C<version>. C<Version::Dotted> extends C<version> —
+C<Version::Dotted> objects are modifiable, but it also narrows C<version> — C<Version::Dotted>
+creates only dotted (aka dotted-decimal) version objects.
 
 =head2 Error Reporting
 
@@ -1068,7 +1077,7 @@ Bumps i-th version part.
     $v->bump( 1 );      # $v == v1.3
     $v->bump( 0 );      # $v == v2
 
-If index is larger than actual number of version parts (minus one), missed parts are autovivified:
+If index is larger than actual number of version parts, missed parts are autovivified:
 
     $v->bump( 5 );      # $v == v2.0.0.0.0.1
 
@@ -1122,12 +1131,15 @@ Shortcut for C<Version::Dotted-E<gt>new>.
 
     $v = qv( $arg );    # same as $v = Version::Dotted->new( $arg );
 
+(If the function is imported from C<Version::Dotted> subclass, it would be shortcut for
+C<Version::Dotted::Subclass-E<gt>new>.)
+
 The function is prototyped. It takes one scalar argument:
 
     ( $v, $w ) = qv v1.2.3, v1.2.3;
 
 C<$v> will be a C<Dotted::Version> object, C<$w> will be a v-string. (C<version>'s C<qv> grabs
-entire list but uses only the first argument, C<$w> would be undefined.)
+entire list but uses only the first argument, C<$w> will be undefined.)
 
 Note: There is no function C<qv> in C<Version::Dotted> package, the function is installed into
 importer package by explicit request, see L</"EXPORT">.
@@ -1259,9 +1271,8 @@ floating-point number, string, or C<version> object:
     version->parse( '0.003010' )    # version object
 
 Floating-point numbers can be compared, but lose trailing zeros. Strings do not lose trailing
-zeros, but cannot be compared (string comparison operators are not suitable for comparing
-versions). C<version> objects does not lose trailing zeros, can be easily compared, but cannot be
-modified.
+zeros, but string comparison operators are not suitable for comparing versions. C<version> objects
+does not lose trailing zeros, can be easily compared, but cannot be modified.
 
 See also: L<version::Internals/Decimal Versions>.
 
@@ -1305,13 +1316,13 @@ contain too many parts due to limited precision of floating-point numbers.
 
 =head2 Non-Stable Releases
 
-Perl terminology in this area in not well-defined and not consistently used:
+Perl terminology in this area is not well-defined and not consistently used:
 
 =over
 
 =item *
 
-The C<version> module declares any version with underscore character (e. g. 'v1.2.3_4') to be an
+The C<version> module declares any version with underscore character (e. g. C<'v1.2.3_4'>) to be an
 "alpha" version. C<version::Internals> refers to CPAN convention "to note unstable releases with an
 underscore in the version string".
 
@@ -1321,7 +1332,7 @@ In turn, C<CPAN::Meta::Spec> defines release status as one of: C<stable>, C<test
 C<unstable>. Word "alpha" is used in the description of C<unstable> release, while C<testing>
 release is described as "beta". There is also requirement that C<stable> release version should not
 contain underscore. (There is no requirement that C<unstanble> and C<testing> releases should
-underscore.)
+contain underscore.)
 
 =item *
 
@@ -1375,7 +1386,7 @@ because
 
 was true before, is false now.
 
-Thus, C<Perl::Version> is broken and it is not clear when and how it will be fixed. But
+Thus, C<Perl::Version> is broken and it is not clear when and I<how> it will be fixed. But
 
 =over
 
@@ -1396,7 +1407,7 @@ I want these methods to work with dotted versions, decimal versions are out of m
 
 (BTW: Requirement #2 effectively means that new method should not rely on underscores.)
 
-C<Version::Dotted> fulfills my requirements.
+C<Version::Dotted> fulfills these requirements.
 
 =for comment ---------------------------------------------------------------------------------------
 
@@ -1428,19 +1439,25 @@ operations. Release status depends on presence of underscore character in versio
 
 =item L<Version::Next>
 
-TODO
+It provides authoring time subroutine to "increment module version numbers simply and correctly",
+works with both dotted and decimal versions, but it "no longer supports dotted-decimals with alpha
+elements".
 
 =item L<SemVer>
 
-TODO
+It implements L<Semantic Versioning 1.0.0|http://semver.org/spec/v1.0.0.html> with no changes (?).
+C<SemVer> allows alphanumeric pre-release versions like C<'1.2.3-alpha1'> and orders them properly:
+1.2.3-alpha < 1.2.3-beta < 1.2.3. However, C<SemVer> is not I<authoring time> tool, it should be
+used in runtime also to provide correct ordering: C<version> does not recognize properly
+pre-release alphanumeric versions.
 
 =item L<Version::Dotted::Semantic>
 
-Subclass implementing adaptation of Semantic Versioning.
+Subclass implementing adaptation of Semantic Versioning, part of this distribution.
 
 =item L<Version::Dotted::Odd>
 
-Subclass implementing odd/even versioning scheme.
+Subclass implementing odd/even versioning scheme, part of this distribution.
 
 =back
 
@@ -1450,7 +1467,7 @@ Van de Bugger <van.de.bugger@gmail.com>
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright (C) 2016 Van de Bugger
+Copyright (C) 2017 Van de Bugger
 
 License GPLv3+: The GNU General Public License version 3 or later
 <http://www.gnu.org/licenses/gpl-3.0.txt>.
